@@ -13,7 +13,10 @@ import (
 // ErrNoTasksHeading is returned if the markdown contains no xc block
 var ErrNoTasksHeading = errors.New("no xc block found")
 
-const trimValues = "_*` "
+const (
+	trimValues       = "_*` "
+	codeBlockStarter = "```"
+)
 
 type parser struct {
 	scanner               *bufio.Scanner
@@ -129,17 +132,26 @@ const (
 	// AttrubuteTypeRun sets the tasks requiredBehaviour, can be always or once.
 	// Default is always
 	AttributeTypeRun
+	// AttributeTypeRunDeps sets the tasks dependenciesBehaviour, can be sync or async.
+	AttributeTypeRunDeps
+	// AttributeTypeInteractive indicates if this is an interactive task
+	// if it is, then logs are not prefixed and the stdout/stderr are passed directly
+	// from the OS
+	AttributeTypeInteractive
 )
 
 var attMap = map[string]AttributeType{
-	"req":         AttributeTypeReq,
-	"requires":    AttributeTypeReq,
-	"env":         AttributeTypeEnv,
-	"environment": AttributeTypeEnv,
-	"dir":         AttributeTypeDir,
-	"directory":   AttributeTypeDir,
-	"inputs":      AttributeTypeInp,
-	"run":         AttributeTypeRun,
+	"req":             AttributeTypeReq,
+	"requires":        AttributeTypeReq,
+	"env":             AttributeTypeEnv,
+	"environment":     AttributeTypeEnv,
+	"dir":             AttributeTypeDir,
+	"directory":       AttributeTypeDir,
+	"inputs":          AttributeTypeInp,
+	"run":             AttributeTypeRun,
+	"rundeps":         AttributeTypeRunDeps,
+	"rundependencies": AttributeTypeRunDeps,
+	"interactive":     AttributeTypeInteractive,
 }
 
 func (p *parser) parseAttribute() (bool, error) {
@@ -180,6 +192,16 @@ func (p *parser) parseAttribute() (bool, error) {
 			return false, fmt.Errorf("run contains invalid behaviour %q should be (always, once): %s", s, p.currTask.Name)
 		}
 		p.currTask.RequiredBehaviour = r
+	case AttributeTypeRunDeps:
+		s := strings.Trim(rest, trimValues)
+		r, ok := models.ParseDepsBehaviour(s)
+		if !ok {
+			return false, fmt.Errorf("runDeps contains invalid behaviour %q should be (sync, async): %s", s, p.currTask.Name)
+		}
+		p.currTask.DepsBehaviour = r
+	case AttributeTypeInteractive:
+		s := strings.Trim(rest, trimValues)
+		p.currTask.Interactive = s == "true"
 	}
 	p.scan()
 	return true, nil
@@ -187,7 +209,7 @@ func (p *parser) parseAttribute() (bool, error) {
 
 func (p *parser) parseCodeBlock() error {
 	t := p.currentLine
-	if len(t) < 3 || t[:3] != "```" {
+	if len(t) < 3 || t[:3] != codeBlockStarter {
 		return nil
 	}
 	if len(p.currTask.Script) > 0 {
@@ -195,7 +217,7 @@ func (p *parser) parseCodeBlock() error {
 	}
 	var ended bool
 	for p.scan() {
-		if len(p.currentLine) >= 3 && p.currentLine[:3] == "```" {
+		if len(p.currentLine) >= 3 && p.currentLine[:3] == codeBlockStarter {
 			ended = true
 			break
 		}
@@ -233,7 +255,9 @@ func (p *parser) parseTaskBody() (bool, error) {
 			return false, err
 		}
 		if p.reachedEnd {
-			return false, nil
+			// parse attribute again in case it is on the last line
+			_, err = p.parseAttribute()
+			return false, err
 		}
 		if ok {
 			continue
